@@ -10,7 +10,32 @@ import importlib
 import pandas as pd
 from pprint import pprint
 from oauth2client.service_account import ServiceAccountCredentials
+import numpy as np
+class NumpyEncoder(json.JSONEncoder):
+    """ Custom encoder for numpy data types """
+    def default(self, obj):
+        if isinstance(obj, (np.int_, np.intc, np.intp, np.int8,
+                            np.int16, np.int32, np.int64, np.uint8,
+                            np.uint16, np.uint32, np.uint64)):
 
+            return int(obj)
+
+        elif isinstance(obj, (np.float_, np.float16, np.float32, np.float64)):
+            return float(obj)
+
+        elif isinstance(obj, (np.complex_, np.complex64, np.complex128)):
+            return {'real': obj.real, 'imag': obj.imag}
+
+        elif isinstance(obj, (np.ndarray,)):
+            return obj.tolist()
+
+        elif isinstance(obj, (np.bool_)):
+            return bool(obj)
+
+        elif isinstance(obj, (np.void)): 
+            return None
+
+        return json.JSONEncoder.default(self, obj)
 
 class EasySpreadsheet():
     
@@ -36,7 +61,8 @@ class EasySpreadsheet():
     def push(self):
         
         cell_list = []
-        for index, row in enumerate(self.table.to_dict(orient='records')):
+        
+        for index, row in enumerate(json.loads(json.dumps(self.table.to_dict(orient='records'), ensure_ascii=False, cls=NumpyEncoder))):
             values = self._make_sheet_row(row.values())
 
             for value_index, value in enumerate(values):
